@@ -2,15 +2,15 @@
 #define KPROCESSORVIEW_H
 
 
-#include <ktoolbar.h>
+#include <tdetoolbar.h>
 #include <knuminput.h>
 #include <tqcheckbox.h>
-#include <klistview.h>
+#include <tdelistview.h>
 
-class MyListView : public KListView
+class MyListView : public TDEListView
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
 		MyListView(TQWidget *parent) ;
 		~MyListView() ;
@@ -20,20 +20,20 @@ class MyListView : public KListView
 
 
 	public slots:
-		void slotContextMenu( KListView *, TQListViewItem *, const TQPoint & ) ;
+		void slotContextMenu( TDEListView *, TQListViewItem *, const TQPoint & ) ;
 
 	signals:
 		void showPopupMenu() ;
 } ;
 
 
-class KProcessorView : public KToolBar
+class TDEProcessorView : public TDEToolBar
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 	public:
-    	KProcessorView(TQWidget *parent = 0, const char *name = 0);
-    	~KProcessorView();
+    	TDEProcessorView(TQWidget *parent = 0, const char *name = 0);
+    	~TDEProcessorView();
 	
 		void setRegisterValues( unsigned char *values ) ;
 		void getRegisterValues( unsigned char *values ) ;
